@@ -165,7 +165,8 @@ class Move:
 
     @classmethod
     def search_sale(cls, name, clause):
-        return [('origin.' + name,) + tuple(clause[1:]) + ('sale.line',)]
+        return [('origin.' + clause[0],) + tuple(clause[1:3])
+            + ('sale.line',) + tuple(clause[3:])]
 
     def get_sale_exception_state(self, name):
         SaleLine = Pool().get('sale.line')
@@ -177,6 +178,18 @@ class Move:
             return 'ignored'
         return ''
 
+    @fields.depends('origin')
+    def on_change_with_product_uom_category(self, name=None):
+        pool = Pool()
+        SaleLine = pool.get('sale.line')
+        category = super(Move, self).on_change_with_product_uom_category(
+            name=name)
+        # Enforce the same unit category as they are used to compute the
+        # remaining quantity to ship and the quantity to invoice.
+        if isinstance(self.origin, SaleLine):
+            category = self.origin.unit.category.id
+        return category
+
     @property
     def origin_name(self):
         pool = Pool()
